@@ -140,12 +140,13 @@ int dbd_db_login(SV* dbh, imp_dbh_t* imp_dbh, char* dbname, char* user,
     /*
      *  Try to connect
      */
-    if (!dbd_db_connect(&imp_dbh->svsock, host, user, password)) {
+    if (!dbd_db_connect(&imp_dbh->svsock, host, user, password, NULL)) {
 	DO_ERROR(dbh, JW_ERR_CONNECT, imp_dbh->svsock);
 	if (copy) free(copy);
 	return FALSE;
     }
 
+#if !defined(DBD_MYSQL)  ||  !defined(MYSQL_VERSION_ID)  ||  (MYSQL_VERSION_ID < 32200)
     /*
      *  Connected, now try to login
      */
@@ -155,6 +156,7 @@ int dbd_db_login(SV* dbh, imp_dbh_t* imp_dbh, char* dbname, char* user,
 	MyClose(imp_dbh->svsock);
 	return FALSE;
     }
+#endif
 
     if (copy) free(copy);
 
@@ -246,6 +248,10 @@ int dbd_db_disconnect(SV* dbh, imp_dbh_t* imp_dbh) {
  **************************************************************************/
 
 int dbd_discon_all (SV *drh, imp_drh_t *imp_drh) {
+#if defined (dTHR)
+    dTHR;
+#endif
+
     /* The disconnect_all concept is flawed and needs more work */
     if (!dirty && !SvTRUE(perl_get_sv("DBI::PERL_ENDING",0))) {
 	sv_setiv(DBIc_ERR(imp_drh), (IV)1);
@@ -525,6 +531,9 @@ int dbd_st_execute(SV* sth, imp_sth_t* imp_sth) {
     D_imp_dbh_from_sth;
     SV** statement;
     int i;
+#if defined (dTHR)
+    dTHR;
+#endif
 
     if (dbis->debug >= 2) {
         fprintf(DBILOGFP, "    -> dbd_st_execute for %08lx\n", (u_long) sth);
@@ -638,10 +647,6 @@ AV* dbd_st_fetch(SV* sth, imp_sth_t* imp_sth) {
 	if (col) {
 	    STRLEN len = strlen(col);
 	    if (ChopBlanks) {
-		while(len && isspace(*col)) {
-		    ++col;
-		    --len;
-		}
 		while(len && isspace(col[len-1])) {
 		    --len;
 		}
@@ -679,6 +684,10 @@ AV* dbd_st_fetch(SV* sth, imp_sth_t* imp_sth) {
  **************************************************************************/
 
 int dbd_st_finish(SV* sth, imp_sth_t* imp_sth) {
+#if defined (dTHR)
+    dTHR;
+#endif
+
     /* Cancel further fetches from this cursor.                 */
     /* We don't close the cursor till DESTROY.                  */
     /* The application may re execute it.                       */
@@ -918,7 +927,9 @@ SV* dbd_st_FETCH_internal(SV* sth, int what, result_t res, int cacheit) {
 	 *  dbd_st_destroy and dbd_st_execute.
 	 */
 	if (cacheit) {
-	    imp_sth->av_attr[what] = (AV*) SvREFCNT_inc((SV*)av);
+	    imp_sth->av_attr[what] = av;
+	} else {
+	    return sv_2mortal(newRV_noinc((SV*) av));
 	}
     }
 
