@@ -82,6 +82,7 @@ int MyConnect(dbh_t sock, char* dsn, char* user, char* password, char* db) {
     char* host = NULL;
     char* port = NULL;
     int portNr;
+    char* unixSocket = NULL;
     int compression = 0;
 
     if (dsn) {
@@ -103,6 +104,8 @@ int MyConnect(dbh_t sock, char* dsn, char* user, char* password, char* db) {
 	        host = copy+9;
 	    } else if (strncmp(copy, "port=", 5) == 0) {
 	        port = copy+5;
+	    } else if (strncmp(copy, "mysql_socket=", 13) == 0) {
+	        unixSocket = copy+13;
 	    } else if (strncmp(copy, "mysql_compression=", 18) == 0) {
 	        compression = atoi(copy+18);
 	    } else {
@@ -151,11 +154,11 @@ int MyConnect(dbh_t sock, char* dsn, char* user, char* password, char* db) {
 	}
 #endif
 	return mysql_real_connect(sock, host, user, password, db, portNr,
-				  NULL, 0) ?
+				  unixSocket, 0) ?
 	    TRUE : FALSE;
 #elif defined(MYSQL_VERSION_ID)  &&  (MYSQL_VERSION_ID >= 32115)
-	return mysql_real_connect(sock, host, user, password, portNr, NULL,
-				  0) ?
+	return mysql_real_connect(sock, host, user, password, portNr,
+				  unixSocket, 0) ?
 	    TRUE : FALSE;
 #else
 	return mysql_real_connect(sock, host, user, password, portNr, NULL) ?
