@@ -16,7 +16,7 @@ use DynaLoader();
 use Carp ();
 @ISA = qw(DynaLoader);
 
-$VERSION = '2.0099';
+$VERSION = '2.009901';
 
 bootstrap DBD::mSQL $VERSION;
 
@@ -248,10 +248,10 @@ of the I<mysql-modules> and I<Msql-modules> packages, respectively.
 
     use DBI;
 
-    $dsn = "DBI:mysql:$database";
-    $dsn = "DBI:mysql:$database:$hostname";
-    $dsn = "DBI:mysql:$database:$hostname:$port";
-    $dsn = "DBI:mysql:$database:$hostname:$port;mysql_compression=1";
+    $dsn = "DBI:mysql:$database;$options";
+    $dsn = "DBI:mysql:$database;$hostname;$options";
+    $dsn = "DBI:mysql:$database;$hostname:$port;$options";
+    $dsn = "DBI:mysql:$database;$hostname:$port;$options";
 
     $dbh = DBI->connect($dsn, $user, $password);
 
@@ -266,9 +266,29 @@ you may explicitly state the port number to connect to in the C<hostname>
 argument, by concatenating the I<hostname> and I<port number> together
 separated by a colon ( C<:> ) character.
 
-As of MySQL 3.22.3, a new feature is supported: If you finish your DSN
-with ";mysql_compression=1", then the communication between client and
-server will be compressed.
+Other options, possibly separated by semicolons, are:
+
+=over 8
+
+=item mysql_compression
+
+As of MySQL 3.22.3, a new feature is supported: If you use the option
+
+    mysql_compression=1
+
+then the communication between client and server will be compressed.
+
+=item mysql_socket
+
+As of MySQL 3.21.15, it is possible to choose the Unix socket that is
+used for connecting to the server. This is done, for example, with
+
+    mysql_socket=/dev/mysql
+
+Usually there's no need for this option, unless you are using another
+location for the socket than that built into the client.
+
+=back
 
 =back
 
@@ -608,69 +628,22 @@ call. If another connect call uses another port and the handles
 are used simultaneously, they will interfere. I doubt that this
 will ever change.
 
-Please speak up now (June 1997) if you encounter additional bugs. I'm
-still learning about the DBI API and can neither judge the quality of
-the code presented here nor the DBI compliancy. But I'm intending to
-resolve things quickly as I'd really like to get rid of the multitude
-of implementations ASAP.
+Msql-2.0.4 and 2.0.4.1 contain a bug that makes ORDER BY and hence
+the test script C<t/40bindparam> fail. To verify, if this is the
+case for you, do a
 
-When running "make test", you will notice that some test scripts fail.
-This is due to bugs in the respective databases, not in the DBI drivers:
+	cd Msql
+	perl -w -I../blib/lib -I../blib/arch t/40bindparam.t
 
-=over 4
-
-=item Nulls
-
-mSQL seems to have problems with NULL's: The following fails with
-mSQL 2.0.1 running on a Linux 2.0.30 machine:
-
-    [joe@laptop Msql-modules-1.18]$ msql test
-    Welcome to the miniSQL monitor.  Type \h for help.
-    mSQL > CREATE TABLE foo (id INTEGER, name CHAR(6))\g
-    Query OK.  1 row(s) modified or retrieved.
-    mSQL > INSERT INTO foo VALUES (NULL, 'joe')\g
-    Query OK.  1 row(s) modified or retrieved.
-    mSQL > SELECT * FROM foo WHERE id = NULL\g
-    Query OK.  0 row(s) modified or retrieved.
-    +----------+------+
-    | id       | name |
-    +----------+------+
-    +----------+------+
-    mSQL > 
-
-=item Blanks
-
-mysql has problems with Blanks on the right side of string fields: They
-get chopped of. (Tested with mysql 3.20.25 on a Linux 2.0.30 machine.)
-
-    [joe@laptop Msql-modules-1.18]$ mysql test
-    Welcome to the mysql monitor.  Commands ends with ; or \g.
-    Type 'help' for help.
-    mysql> CREATE TABLE foo (id INTEGER, bar CHAR(8));
-    Query OK, 0 rows affected (0.10 sec)
-    mysql> INSERT INTO foo VALUES (1, ' a b c ');
-    Query OK, 1 rows affected (0.00 sec)
-    mysql> SELECT * FROM foo;
-    1 rows in set (0.19 sec)
-    +------+--------+
-    | id   | bar    |
-    +------+--------+
-    |    1 |  a b c |
-    +------+--------+
-    mysql> quit;
-    [joe@laptop Msql-modules-1.18]$ mysqldump test foo
-
-    [deleted]
-
-    INSERT INTO foo VALUES (1,' a b c');
-
-=back
+If something is wrong, the script ought to print a number of id's and
+names. If the id's aren't in order, it is likely, that your mSQL has
+a bug. See the INSTALL file for a patch.
 
 
 =head1 AUTHOR
 
 B<DBD::mSQL> has been primarily written by Alligator Descartes
-(I<descarte@hermetica.com>), who has been aided and abetted by Gary
+(I<descarte@arcana.co.uk>), who has been aided and abetted by Gary
 Shea, Andreas Koenig and Tim Bunce amongst others. Apologies if your
 name isn't listed, it probably is in the file called
 'Acknowledgments'. As of version 0.80 the maintainer is Andreas Knig.
@@ -692,7 +665,7 @@ current version and all credits and copyright notices are retained (
 the I<AUTHOR> and I<COPYRIGHT> sections ).  Requests for other
 distribution rights, including incorporation into commercial products,
 such as books, magazine articles or CD-ROMs should be made to
-Alligator Descartes <I<descarte@hermetica.com>>.
+Alligator Descartes <I<descarte@arcana.co.uk>>.
 
 
 =head1 MAILING LIST SUPPORT
@@ -729,7 +702,7 @@ Mailing list archives are at
 Additional information on the DBI project can be found on the World
 Wide Web at the following URL:
 
-    http://www.hermetica.com/technologia/perl/DBI
+    http://www.arcana.co.uk/technologia/perl/DBI
 
 where documentation, pointers to the mailing lists and mailing list
 archives and pointers to the most current versions of the modules can
